AppAutoSizeText class
Constructors
AppAutoSizeText (String data , {Key ? key , Key ? textKey , TextStyle ? style , StrutStyle ? strutStyle , double ? minFontSize , double maxFontSize = double.infinity , double stepGranularity = 1 , List <double > ? presetFontSizes , AutoSizeGroup? group , TextAlign ? textAlign , TextDirection ? textDirection , Locale ? locale , bool ? softWrap , bool wrapWords = true , TextOverflow ? overflow , Widget ? overflowReplacement , double ? textScaleFactor , int ? maxLines , String ? semanticsLabel })
Properties
data
→ String ?
The text to display.
final inherited
group
→ AutoSizeGroup?
Synchronizes the size of multiple AutoSizeTexts.
final inherited
hashCode
→ int
The hash code for this object.
no setter inherited
key
→ Key ?
Controls how one widget replaces another widget in the tree.
final inherited
locale
→ Locale ?
Used to select a font when the same Unicode character can
be rendered differently, depending on the locale.
final inherited
maxFontSize
→ double
The maximum text size constraint to be used when auto-sizing text.
final inherited
maxLines
→ int ?
An optional maximum number of lines for the text to span, wrapping if necessary.
If the text exceeds the given number of lines, it will be resized according
to the specified bounds and if necessary truncated according to overflow.
final inherited
minFontSize
→ double
The minimum text size constraint to be used when auto-sizing text.
final inherited
overflow
→ TextOverflow ?
How visual overflow should be handled.
final inherited
overflowReplacement
→ Widget ?
If the text is overflowing and does not fit its bounds, this widget is
displayed instead.
final inherited
presetFontSizes
→ List <double > ?
Predefines all the possible font sizes.
final inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
semanticsLabel
→ String ?
An alternative semantics label for this text.
final inherited
softWrap
→ bool ?
Whether the text should break at soft line breaks.
final inherited
stepGranularity
→ double
The step size in which the font size is being adapted to constraints.
final inherited
strutStyle
→ StrutStyle ?
The strut style to use. Strut style defines the strut, which sets minimum
vertical layout metrics.
final inherited
style
→ TextStyle ?
If non-null, the style to use for this text.
final inherited
textAlign
→ TextAlign ?
How the text should be aligned horizontally.
final inherited
textDirection
→ TextDirection ?
The directionality of the text.
final inherited
textKey
→ Key ?
Sets the key for the resulting Text widget.
final inherited
textScaleFactor
→ double ?
The number of font pixels for each logical pixel.
final inherited
textSpan
→ TextSpan ?
The text to display as a TextSpan .
final inherited
wrapWords
→ bool
Whether words which don't fit in one line should be wrapped.
final inherited
virnavi_ui_bootstrap 0.0.1