widgets/screen/screen library

Classes

NoScreenData<S extends Screen>
A no-op ScreenData used by screens that have no data to share across layouts. This is the default returned by Screen.createScreenData.
Screen
ScreenData<S extends Screen>
Holds data shared across all ScreenLayouts of a Screen.
ScreenLayout<S extends Screen>
The base class for all layouts returned by Screen.buildMobilePortrait, Screen.buildMobileLandscape, Screen.buildTabletPortrait, and Screen.buildTabletLandscape.