didUpdateWidget method
Called when the parent widget rebuilds with a new configuration.
Implementation
@protected
void didUpdateWidget(covariant ScreenLayout<S> oldWidget) {}
Called when the parent widget rebuilds with a new configuration.
@protected
void didUpdateWidget(covariant ScreenLayout<S> oldWidget) {}