mounted property
bool
get
mounted
Whether this layout is currently mounted in the widget tree.
Implementation
bool get mounted => _stateRef?.mounted ?? false;
Whether this layout is currently mounted in the widget tree.
bool get mounted => _stateRef?.mounted ?? false;