VirnaviUIBootstrap class
Entry point for configuring the virnavi_ui_bootstrap library.
Call VirnaviUIBootstrap.init once at app startup before any Screen widget is built.
void main() {
VirnaviUIBootstrap.init(
mobileDesignSize: const Size(390, 844),
tabletDesignSize: const Size(768, 1024),
);
runApp(const MyApp());
}
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- mobileDesignSize → Size
-
The portrait design size for mobile devices.
Landscape is derived by swapping width and height.
no setter
- tabletDesignSize → Size
-
The portrait design size for tablet devices.
Landscape is derived by swapping width and height.
no setter