AppAutoSizeText class

Inheritance

Constructors

AppAutoSizeText(String data, {Key? key, Key? textKey, TextStyle? style, StrutStyle? strutStyle, double? minFontSize, double maxFontSize = double.infinity, double stepGranularity = 1, List<double>? presetFontSizes, AutoSizeGroup? group, TextAlign? textAlign, TextDirection? textDirection, Locale? locale, bool? softWrap, bool wrapWords = true, TextOverflow? overflow, Widget? overflowReplacement, double? textScaleFactor, int? maxLines, String? semanticsLabel})

Properties

data String?
The text to display.
finalinherited
group → AutoSizeGroup?
Synchronizes the size of multiple AutoSizeTexts.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
locale Locale?
Used to select a font when the same Unicode character can be rendered differently, depending on the locale.
finalinherited
maxFontSize double
The maximum text size constraint to be used when auto-sizing text.
finalinherited
maxLines int?
An optional maximum number of lines for the text to span, wrapping if necessary. If the text exceeds the given number of lines, it will be resized according to the specified bounds and if necessary truncated according to overflow.
finalinherited
minFontSize double
The minimum text size constraint to be used when auto-sizing text.
finalinherited
overflow TextOverflow?
How visual overflow should be handled.
finalinherited
overflowReplacement Widget?
If the text is overflowing and does not fit its bounds, this widget is displayed instead.
finalinherited
presetFontSizes List<double>?
Predefines all the possible font sizes.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticsLabel String?
An alternative semantics label for this text.
finalinherited
softWrap bool?
Whether the text should break at soft line breaks.
finalinherited
stepGranularity double
The step size in which the font size is being adapted to constraints.
finalinherited
strutStyle StrutStyle?
The strut style to use. Strut style defines the strut, which sets minimum vertical layout metrics.
finalinherited
style TextStyle?
If non-null, the style to use for this text.
finalinherited
textAlign TextAlign?
How the text should be aligned horizontally.
finalinherited
textDirection TextDirection?
The directionality of the text.
finalinherited
textKey Key?
Sets the key for the resulting Text widget.
finalinherited
textScaleFactor double?
The number of font pixels for each logical pixel.
finalinherited
textSpan TextSpan?
The text to display as a TextSpan.
finalinherited
wrapWords bool
Whether words which don't fit in one line should be wrapped.
finalinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _AutoSizeTextState
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited