NoScreenData<S extends Screen> class
A no-op ScreenData used by screens that have no data to share across layouts. This is the default returned by Screen.createScreenData.
- Inheritance
-
- Object
- ScreenData<
S> - NoScreenData
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setState(
VoidCallback fn) → void -
Rebuilds the currently visible ScreenLayout.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited