widgets/widgets library

Classes

AppAutoSizeText
AppSvgImage
SvgImage shows a svg asset or a precompiled svg based on the provided asset path. To precompile svg assets on app build edit your pubspecs.yaml and listeners transformers like : assets: - assets/images/svg/ - path: assets/images/svg/precompiled/ transformers: - package: vector_graphics_compiler - google_fonts/
ErrorTextSnackBar
FutureModelStreamBuilder<M>
FutureModelStreamListener<M>
FutureMultiStreamBuilder
FutureMultiStreamListener
FutureOptionalBuilder<M>
FutureStreamListener<M>
NoScreenData<S extends Screen>
A no-op ScreenData used by screens that have no data to share across layouts. This is the default returned by Screen.createScreenData.
Screen
ScreenData<S extends Screen>
Holds data shared across all ScreenLayouts of a Screen.
ScreenLayout<S extends Screen>
The base class for all layouts returned by Screen.buildMobilePortrait, Screen.buildMobileLandscape, Screen.buildTabletPortrait, and Screen.buildTabletLandscape.
SectionBox
SectionBoxEnd
SectionBoxMid
SectionBoxStart